@@ -28,10 +28,7 @@
   WRITE_16((unsigned char*)(buff) + 2, (n) >> 16); \
 } while(0)
 
-int ZEXPORT unzRepair(const char* file, const char* fileOut,
-                      const char* fileOutTmp, uLong* nRecovered,
-                      uLong* bytesRecovered)
-{
+extern int ZEXPORT unzRepair(const char* file, const char* fileOut, const char* fileOutTmp, uLong* nRecovered, uLong* bytesRecovered) {
   int err = Z_OK;
   FILE* fpZip = fopen(file, "rb");
   FILE* fpOut = fopen(fileOut, "wb");
